@@ -6,7 +6,7 @@ use warnings;
 use base qw( Device::Chip::Adapter );
 use Carp qw/croak/;
 
-our $VERSION = '0.00004';
+our $VERSION = '0.00005';
 
 require XSLoader;
 XSLoader::load();
@@ -19,7 +19,12 @@ sub configure {
     my $self = shift;
     my %args = @_;
 
-    $self->{spidev} = Device::Chip::Adapter::LinuxKernel::_SPI::_spidev_open("/dev/spidev0.0");
+    if (defined $self->{spidev})
+    {
+        _spidev_close($self->{spidev});
+    }
+
+    $self->{spidev} = Device::Chip::Adapter::LinuxKernel::_SPI::_spidev_open("/dev/".$self->{spi_bus});
     Device::Chip::Adapter::LinuxKernel::_SPI::_spidev_set_mode($self->{spidev}, $args{mode})
 	if defined $args{mode};
     Device::Chip::Adapter::LinuxKernel::_SPI::_spidev_set_speed($self->{spidev}, $args{max_bitrate})
@@ -28,11 +33,20 @@ sub configure {
     Future->done($self);
 }
 
+sub DESTROY {
+    my $self = shift;
+
+    if (defined $self->{spidev})
+    {
+        _spidev_close($self->{spidev});
+    }
+}
+
 sub readwrite {
     my $self = shift;
     my $bytes = shift;
 
-    my $bytes_in = Device::Chip::Adapter::LinuxKernel::_SPI::_spidev_transfer($self->{spidev}, $bytes);
+    my $bytes_in = _spidev_transfer($self->{spidev}, $bytes);
 
     Future->done($bytes_in);
 }
